@@ -98,7 +98,7 @@ class ManageFiles():
                 with requests.post(url, file, headers=headers, stream=True) as req:
                     for i in req.iter_lines():
                         response += str(i)
-            response = json.loads(req.text)
+            print(req)
 
             
             # Closing post request after finishing upload
